Vec4

Struct Vec4 

#[repr(C, align(16))]
pub struct Vec4 { pub x: f32, pub y: f32, pub z: f32, pub w: f32, }

Fields

x: f32y: f32z: f32w: f32

Implementations

Source

impl Vec4

pub const ZERO: Vec4

pub const ONE: Vec4

pub const fn new(x: f32, y: f32, z: f32, w: f32) -> Self

pub fn length(self) -> f32

pub fn length_squared(self) -> f32

pub fn normalize(self) -> Self

pub fn normalize_fast(self) -> Self

Normalize using rsqrt approximation. Less accurate than normalize() but faster; uses SIMD when the feature is on.

pub fn dot(self, other: Self) -> f32

pub fn lerp(self, other: Self, t: f32) -> Self

pub fn min(self, other: Self) -> Self

pub fn max(self, other: Self) -> Self

pub fn splat(value: f32) -> Self

All components set to the same value.

pub fn abs(self) -> Self

Component-wise absolute value

pub fn recip(self) -> Self

Component-wise reciprocal

pub fn signum(self) -> Self

Component-wise signum

pub fn min_element(self) -> f32

Minimum element

pub fn max_element(self) -> f32

Maximum element

pub fn clamp(self, min: Self, max: Self) -> Self

Component-wise clamp

pub fn truncate(self) -> Vec3

Truncate to Vec3 (drop w component)

pub fn is_finite(self) -> bool

Check if all components are finite

pub fn is_nan(self) -> bool

Check if any component is NaN

pub fn abs_diff_eq(self, other: Self, epsilon: f32) -> bool

Approximate equality with epsilon

pub fn from_array(a: [f32; 4]) -> Self

Create from array

pub fn to_array(self) -> [f32; 4]

Convert to array

pub fn from_slice(slice: &[f32]) -> Option<Self>

Create from slice, returns None if slice is too short

pub fn write_to_slice(self, slice: &mut [f32])

Write to slice, panics if slice is too short

pub fn as_array(&self) -> &[f32; 4]

Get reference to underlying array

pub fn as_array_mut(&mut self) -> &mut [f32; 4]

Get mutable reference to underlying array